[nautilus-actions/file-manager-actions] NAIDuplicable interface is renamed to FMAIDuplicable



commit e0327429c2f200c330b25b4b9f8afc9e3a7146f1
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 22:05:31 2015 +0200

    NAIDuplicable interface is renamed to FMAIDuplicable

 src/api/Makefile.am                              |    2 +-
 src/api/{na-iduplicable.h => fma-iduplicable.h}  |   70 ++++----
 src/api/na-object-api.h                          |   16 +-
 src/core/Makefile.am                             |    2 +-
 src/core/fma-icontext.c                          |    4 +-
 src/core/{na-iduplicable.c => fma-iduplicable.c} |  230 +++++++++++-----------
 src/core/na-marshal.def                          |    4 +-
 src/core/na-object-item.c                        |    2 +-
 src/core/na-object.c                             |   34 ++--
 src/nact/nact-assistant-export.c                 |    2 +-
 src/nact/nact-clipboard.c                        |    2 +-
 src/nact/nact-tree-ieditable.c                   |    2 +-
 12 files changed, 185 insertions(+), 185 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index 253a954..73e980f 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -45,7 +45,7 @@ api_include_HEADERS = \
        fma-gconf-monitor.h                                                                     \
        fma-gconf-utils.h                                                                       \
        fma-icontext.h                                                                          \
-       na-iduplicable.h                                                                        \
+       fma-iduplicable.h                                                                       \
        na-ifactory-object.h                                                            \
        na-ifactory-object-data.h                                                       \
        na-object-api.h                                                                         \
diff --git a/src/api/na-object-api.h b/src/api/na-object-api.h
index 8a1193d..1008b27 100644
--- a/src/api/na-object-api.h
+++ b/src/api/na-object-api.h
@@ -43,7 +43,7 @@
 
 #include "na-ifactory-object.h"
 #include "na-ifactory-object-data.h"
-#include "na-iduplicable.h"
+#include "fma-iduplicable.h"
 #include "fma-icontext.h"
 #include "na-object-action.h"
 #include "na-object-profile.h"
@@ -51,16 +51,16 @@
 
 G_BEGIN_DECLS
 
-/* NAIDuplicable
+/* FMAIDuplicable
  */
-#define na_object_duplicate( obj, mode )                na_iduplicable_duplicate( NA_IDUPLICABLE( obj ), 
mode )
+#define na_object_duplicate( obj, mode )                fma_iduplicable_duplicate( FMA_IDUPLICABLE( obj ), 
mode )
 #define na_object_check_status( obj )                   na_object_object_check_status_rec( NA_OBJECT( obj ))
 
-#define na_object_get_origin( obj )                     na_iduplicable_get_origin( NA_IDUPLICABLE( obj ))
-#define na_object_is_valid( obj )                       na_iduplicable_is_valid( NA_IDUPLICABLE( obj ))
-#define na_object_is_modified( obj )                    na_iduplicable_is_modified( NA_IDUPLICABLE( obj ))
+#define na_object_get_origin( obj )                     fma_iduplicable_get_origin( FMA_IDUPLICABLE( obj ))
+#define na_object_is_valid( obj )                       fma_iduplicable_is_valid( FMA_IDUPLICABLE( obj ))
+#define na_object_is_modified( obj )                    fma_iduplicable_is_modified( FMA_IDUPLICABLE( obj ))
 
-#define na_object_set_origin( obj, origin )             na_iduplicable_set_origin( NA_IDUPLICABLE( obj ), ( 
NAIDuplicable * )( origin ))
+#define na_object_set_origin( obj, origin )             fma_iduplicable_set_origin( FMA_IDUPLICABLE( obj ), 
( FMAIDuplicable * )( origin ))
 #define na_object_reset_origin( obj, origin )           na_object_object_reset_origin( NA_OBJECT( obj ), ( 
NAObject * )( origin ))
 
 /* NAObject
@@ -213,7 +213,7 @@ G_BEGIN_DECLS
 #define na_object_set_capabilities( obj, cap )          na_ifactory_object_set_from_void( 
NA_IFACTORY_OBJECT( obj ), NAFO_DATA_CAPABILITITES, ( const void * )( cap ))
 
 #ifdef NA_ENABLE_DEPRECATED
-#define na_object_set_modified( obj, modified )         na_iduplicable_set_modified( NA_IDUPLICABLE( obj ), 
( modified ))
+#define na_object_set_modified( obj, modified )         fma_iduplicable_set_modified( FMA_IDUPLICABLE( obj 
), ( modified ))
 #endif
 
 G_END_DECLS
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 82a3249..9bc8dfa 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -78,7 +78,7 @@ libna_core_la_SOURCES = \
        na-gtk-utils.h                                                                          \
        fma-icontext.c                                                                          \
        fma-icontext-factory.c                                                          \
-       na-iduplicable.c                                                                        \
+       fma-iduplicable.c                                                                       \
        na-iexporter.c                                                                          \
        na-ifactory-object.c                                                            \
        na-ifactory-provider.c                                                          \
diff --git a/src/core/fma-icontext.c b/src/core/fma-icontext.c
index 30a5e6c..e4f90fb 100644
--- a/src/core/fma-icontext.c
+++ b/src/core/fma-icontext.c
@@ -255,8 +255,8 @@ fma_icontext_is_candidate( const FMAIContext *context, guint target, GList *sele
  *
  * Returns: %TRUE if this @context is valid, %FALSE else.
  *
- * This function is part of <methodname>NAIDuplicable::check_status</methodname>
- * and is called by #NAIDuplicable objects which also implement #FMAIContext
+ * This function is part of <methodname>FMAIDuplicable::check_status</methodname>
+ * and is called by #FMAIDuplicable objects which also implement #FMAIContext
  * interface. It so doesn't make sense of asking the object for its
  * validity status as it has already been checked before calling the
  * function.
diff --git a/src/core/na-iduplicable.c b/src/core/fma-iduplicable.c
similarity index 57%
rename from src/core/na-iduplicable.c
rename to src/core/fma-iduplicable.c
index 6fdec43..1d86daa 100644
--- a/src/core/na-iduplicable.c
+++ b/src/core/fma-iduplicable.c
@@ -31,26 +31,26 @@
 #include <config.h>
 #endif
 
-#include "api/na-iduplicable.h"
+#include "api/fma-iduplicable.h"
 
 /* private interface data
  */
-struct _NAIDuplicableInterfacePrivate {
+struct _FMAIDuplicableInterfacePrivate {
        GList *consumers;
 };
 
-/* the data sructure set on each NAIDuplicable object
+/* the data sructure set on each FMAIDuplicable object
  */
 typedef struct {
-       NAIDuplicable *origin;
+       FMAIDuplicable *origin;
        gboolean       modified;
        gboolean       valid;
 }
        DuplicableStr;
 
-#define NA_IDUPLICABLE_DATA_DUPLICABLE                 "na-iduplicable-data-duplicable"
+#define FMA_IDUPLICABLE_DATA_DUPLICABLE                        "fma-iduplicable-data-duplicable"
 
-/* signals emitted on NAIDuplicable when a status changes
+/* signals emitted on FMAIDuplicable when a status changes
  */
 enum {
        MODIFIED_CHANGED,
@@ -58,27 +58,27 @@ enum {
        LAST_SIGNAL
 };
 
-static NAIDuplicableInterface *st_interface = NULL;
+static FMAIDuplicableInterface *st_interface = NULL;
 static guint                   st_initializations = 0;
 static gint                    st_signals[ LAST_SIGNAL ] = { 0 };
 
 static GType          register_type( void );
-static void           interface_base_init( NAIDuplicableInterface *klass );
-static void           interface_base_finalize( NAIDuplicableInterface *klass );
+static void           interface_base_init( FMAIDuplicableInterface *klass );
+static void           interface_base_finalize( FMAIDuplicableInterface *klass );
 
-static void           v_copy( NAIDuplicable *target, const NAIDuplicable *source, guint mode );
-static gboolean       v_are_equal( const NAIDuplicable *a, const NAIDuplicable *b );
-static gboolean       v_is_valid( const NAIDuplicable *object );
+static void           v_copy( FMAIDuplicable *target, const FMAIDuplicable *source, guint mode );
+static gboolean       v_are_equal( const FMAIDuplicable *a, const FMAIDuplicable *b );
+static gboolean       v_is_valid( const FMAIDuplicable *object );
 
-static DuplicableStr *get_duplicable_str( const NAIDuplicable *object );
+static DuplicableStr *get_duplicable_str( const FMAIDuplicable *object );
 
-static void           on_modified_changed_class_handler( NAIDuplicable *instance, GObject *object, gboolean 
is_modified );
-static void           on_valid_changed_class_handler( NAIDuplicable *instance, GObject *object, gboolean 
is_valid );
-static void           propagate_signal_to_consumers( NAIDuplicable *instance, const gchar *signal, GObject 
*object, gboolean new_status );
+static void           on_modified_changed_class_handler( FMAIDuplicable *instance, GObject *object, gboolean 
is_modified );
+static void           on_valid_changed_class_handler( FMAIDuplicable *instance, GObject *object, gboolean 
is_valid );
+static void           propagate_signal_to_consumers( FMAIDuplicable *instance, const gchar *signal, GObject 
*object, gboolean new_status );
 static void           release_signal_consumers( GList *consumers );
 
 GType
-na_iduplicable_get_type( void )
+fma_iduplicable_get_type( void )
 {
        static GType iface_type = 0;
 
@@ -92,11 +92,11 @@ na_iduplicable_get_type( void )
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "na_iduplicable_register_type";
+       static const gchar *thisfn = "fma_iduplicable_register_type";
        GType type;
 
        static const GTypeInfo info = {
-               sizeof( NAIDuplicableInterface ),
+               sizeof( FMAIDuplicableInterface ),
                ( GBaseInitFunc ) interface_base_init,
                ( GBaseFinalizeFunc ) interface_base_finalize,
                NULL,
@@ -109,7 +109,7 @@ register_type( void )
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( G_TYPE_INTERFACE, "NAIDuplicable", &info, 0 );
+       type = g_type_register_static( G_TYPE_INTERFACE, "FMAIDuplicable", &info, 0 );
 
        g_type_interface_add_prerequisite( type, G_TYPE_OBJECT );
 
@@ -117,15 +117,15 @@ register_type( void )
 }
 
 static void
-interface_base_init( NAIDuplicableInterface *klass )
+interface_base_init( FMAIDuplicableInterface *klass )
 {
-       static const gchar *thisfn = "na_iduplicable_interface_base_init";
+       static const gchar *thisfn = "fma_iduplicable_interface_base_init";
 
        if( !st_initializations ){
 
                g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
-               klass->private = g_new0( NAIDuplicableInterfacePrivate, 1 );
+               klass->private = g_new0( FMAIDuplicableInterfacePrivate, 1 );
 
                klass->private->consumers = NULL;
 
@@ -134,9 +134,9 @@ interface_base_init( NAIDuplicableInterface *klass )
                klass->is_valid = NULL;
 
                /**
-                * NAIDuplicable::modified-changed:
+                * FMAIDuplicable::modified-changed:
                 *
-                * This signal is emitted by #NAIDuplicable when the modification
+                * This signal is emitted by #FMAIDuplicable when the modification
                 * status of an object has been modified.
                 *
                 * The default class handler propagates the signal to registered
@@ -145,9 +145,9 @@ interface_base_init( NAIDuplicableInterface *klass )
                 * Signal args: New modification status
                 *
                 * Handler prototype:
-                * void ( *handler )( NAIDuplicable *duplicable, NAObject *object, gboolean is_modified, 
gpointer user_data );
+                * void ( *handler )( FMAIDuplicable *duplicable, NAObject *object, gboolean is_modified, 
gpointer user_data );
                 *
-                * When the signal is first emitted, thus on NAIDuplicable, @duplicable
+                * When the signal is first emitted, thus on FMAIDuplicable, @duplicable
                 * and @object are pointers to the same address. This duplication is
                 * relevant when propagating the signal to customer, as the signal is
                 * emitted on the customer itself, while we still need the @object
@@ -166,9 +166,9 @@ interface_base_init( NAIDuplicableInterface *klass )
                                G_TYPE_POINTER, G_TYPE_BOOLEAN );
 
                /**
-                * NAIDuplicable::valid-changed:
+                * FMAIDuplicable::valid-changed:
                 *
-                * This signal is emitted by #NAIDuplicable when the validity
+                * This signal is emitted by #FMAIDuplicable when the validity
                 * status of an object has been modified.
                 *
                 * The default class handler propagates the signal to registered
@@ -177,9 +177,9 @@ interface_base_init( NAIDuplicableInterface *klass )
                 * Signal args: New validity status
                 *
                 * Handler prototype:
-                * void ( *handler )( NAIDuplicable *duplicable, NAObject *object, gboolean is_valid, 
gpointer user_data );
+                * void ( *handler )( FMAIDuplicable *duplicable, NAObject *object, gboolean is_valid, 
gpointer user_data );
                 *
-                * When the signal is first emitted, thus on NAIDuplicable, @duplicable
+                * When the signal is first emitted, thus on FMAIDuplicable, @duplicable
                 * and @object are pointers to the same address. This duplication is
                 * relevant when propagating the signal to customer, as the signal is
                 * emitted on the customer itself, while we still need the @object
@@ -204,9 +204,9 @@ interface_base_init( NAIDuplicableInterface *klass )
 }
 
 static void
-interface_base_finalize( NAIDuplicableInterface *klass )
+interface_base_finalize( FMAIDuplicableInterface *klass )
 {
-       static const gchar *thisfn = "na_iduplicable_interface_base_finalize";
+       static const gchar *thisfn = "fma_iduplicable_interface_base_finalize";
 
        st_initializations -= 1;
 
@@ -221,33 +221,33 @@ interface_base_finalize( NAIDuplicableInterface *klass )
 }
 
 /**
- * na_iduplicable_dispose:
- * @object: the #NAIDuplicable object to be initialized.
+ * fma_iduplicable_dispose:
+ * @object: the #FMAIDuplicable object to be initialized.
  *
  * Releases resources.
  *
  * Since: 2.30
  */
 void
-na_iduplicable_dispose( const NAIDuplicable *object )
+fma_iduplicable_dispose( const FMAIDuplicable *object )
 {
        DuplicableStr *str;
 
-       g_return_if_fail( NA_IS_IDUPLICABLE( object ));
+       g_return_if_fail( FMA_IS_IDUPLICABLE( object ));
 
        str = get_duplicable_str( object );
        g_free( str );
-       g_object_set_data( G_OBJECT( object ), NA_IDUPLICABLE_DATA_DUPLICABLE, NULL );
+       g_object_set_data( G_OBJECT( object ), FMA_IDUPLICABLE_DATA_DUPLICABLE, NULL );
 }
 
 /**
- * na_iduplicable_dump:
- * @object: the #NAIDuplicable object to be dumped.
+ * fma_iduplicable_dump:
+ * @object: the #FMAIDuplicable object to be dumped.
  *
  * Dumps via g_debug the properties of the object.
  *
  * We ouput here only the data we set ourselves againt the
- * #NAIDuplicable -implemented object.
+ * #FMAIDuplicable -implemented object.
  *
  * This function should be called by the implementation when it dumps
  * itself its own content.
@@ -255,12 +255,12 @@ na_iduplicable_dispose( const NAIDuplicable *object )
  * Since: 2.30
  */
 void
-na_iduplicable_dump( const NAIDuplicable *object )
+fma_iduplicable_dump( const FMAIDuplicable *object )
 {
-       static const gchar *thisfn = "na_iduplicable_dump";
+       static const gchar *thisfn = "fma_iduplicable_dump";
        DuplicableStr *str;
 
-       g_return_if_fail( NA_IS_IDUPLICABLE( object ));
+       g_return_if_fail( FMA_IS_IDUPLICABLE( object ));
 
        str = get_duplicable_str( object );
 
@@ -270,26 +270,26 @@ na_iduplicable_dump( const NAIDuplicable *object )
 }
 
 /**
- * na_iduplicable_duplicate:
- * @object: the #NAIDuplicable object to be duplicated.
+ * fma_iduplicable_duplicate:
+ * @object: the #FMAIDuplicable object to be duplicated.
  * @mode: the %DuplicableMode duplication mode.
  *
- * Exactly duplicates a #NAIDuplicable -implemented object, including
+ * Exactly duplicates a #FMAIDuplicable -implemented object, including
  * modification and validity status which are copied from @object to
  * the duplicated one.
  *
- * Returns: a new #NAIDuplicable.
+ * Returns: a new #FMAIDuplicable.
  *
  * Since: 2.30
  */
-NAIDuplicable *
-na_iduplicable_duplicate( const NAIDuplicable *object, guint mode )
+FMAIDuplicable *
+fma_iduplicable_duplicate( const FMAIDuplicable *object, guint mode )
 {
-       static const gchar *thisfn = "na_iduplicable_duplicate";
-       NAIDuplicable *dup;
+       static const gchar *thisfn = "fma_iduplicable_duplicate";
+       FMAIDuplicable *dup;
        DuplicableStr *dup_str, *obj_str;
 
-       g_return_val_if_fail( NA_IS_IDUPLICABLE( object ), NULL );
+       g_return_val_if_fail( FMA_IS_IDUPLICABLE( object ), NULL );
 
        g_debug( "%s: object=%p (%s)",
                        thisfn,
@@ -302,7 +302,7 @@ na_iduplicable_duplicate( const NAIDuplicable *object, guint mode )
        dup_str = get_duplicable_str( dup );
        obj_str = get_duplicable_str( object );
 
-       dup_str->origin = ( NAIDuplicable * ) object;
+       dup_str->origin = ( FMAIDuplicable * ) object;
        dup_str->modified = obj_str->modified;
        dup_str->valid = obj_str->valid;
 
@@ -310,18 +310,18 @@ na_iduplicable_duplicate( const NAIDuplicable *object, guint mode )
 }
 
 /**
- * na_iduplicable_check_status:
- * @object: the #NAIDuplicable object to be checked.
+ * fma_iduplicable_check_status:
+ * @object: the #FMAIDuplicable object to be checked.
  *
- * Checks the edition status of the #NAIDuplicable object, and set up
+ * Checks the edition status of the #FMAIDuplicable object, and set up
  * the corresponding properties.
  *
  * This function is supposed to be called each time the object may have
  * been modified in order to set the corresponding properties. Helper
- * functions na_iduplicable_is_modified() and na_iduplicable_is_valid()
+ * functions fma_iduplicable_is_modified() and fma_iduplicable_is_valid()
  * will then only return the current value of the properties.
  *
- * na_iduplicable_check_status() is not, as itself, recursive.
+ * fma_iduplicable_check_status() is not, as itself, recursive.
  * That is, the modification and validity status are only set on the
  * specified object.
  * #NAObject implementation has chosen to handle itself the recursivity:
@@ -331,13 +331,13 @@ na_iduplicable_duplicate( const NAIDuplicable *object, guint mode )
  * Since: 2.30
  */
 void
-na_iduplicable_check_status( const NAIDuplicable *object )
+fma_iduplicable_check_status( const FMAIDuplicable *object )
 {
-       static const gchar *thisfn = "na_iduplicable_check_status";
+       static const gchar *thisfn = "fma_iduplicable_check_status";
        DuplicableStr *str;
        gboolean was_modified, was_valid;
 
-       g_return_if_fail( NA_IS_IDUPLICABLE( object ));
+       g_return_if_fail( FMA_IS_IDUPLICABLE( object ));
 
        g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
@@ -348,7 +348,7 @@ na_iduplicable_check_status( const NAIDuplicable *object )
 
        if( str->origin ){
                g_debug( "%s: vs. origin=%p (%s)", thisfn, ( void * ) str->origin, G_OBJECT_TYPE_NAME( 
str->origin ));
-               g_return_if_fail( NA_IS_IDUPLICABLE( str->origin ));
+               g_return_if_fail( FMA_IS_IDUPLICABLE( str->origin ));
                str->modified = !v_are_equal( str->origin, object );
 
        } else {
@@ -371,22 +371,22 @@ na_iduplicable_check_status( const NAIDuplicable *object )
 }
 
 /**
- * na_iduplicable_get_origin:
- * @object: the #NAIDuplicable object whose origin is to be returned.
+ * fma_iduplicable_get_origin:
+ * @object: the #FMAIDuplicable object whose origin is to be returned.
  *
- * Returns the origin of a duplicated #NAIDuplicable.
+ * Returns the origin of a duplicated #FMAIDuplicable.
  *
- * Returns: the original #NAIDuplicable, or NULL.
+ * Returns: the original #FMAIDuplicable, or NULL.
  *
  * Since: 2.30
  */
-NAIDuplicable *
-na_iduplicable_get_origin( const NAIDuplicable *object )
+FMAIDuplicable *
+fma_iduplicable_get_origin( const FMAIDuplicable *object )
 {
-       NAIDuplicable *origin;
+       FMAIDuplicable *origin;
        DuplicableStr *str;
 
-       g_return_val_if_fail( NA_IS_IDUPLICABLE( object ), NULL );
+       g_return_val_if_fail( FMA_IS_IDUPLICABLE( object ), NULL );
 
        str = get_duplicable_str( object );
        origin = str->origin;
@@ -395,8 +395,8 @@ na_iduplicable_get_origin( const NAIDuplicable *object )
 }
 
 /**
- * na_iduplicable_is_valid:
- * @object: the #NAIDuplicable object whose status is to be returned.
+ * fma_iduplicable_is_valid:
+ * @object: the #FMAIDuplicable object whose status is to be returned.
  *
  * Returns the current value of the relevant property
  * without rechecking the edition status itself.
@@ -406,12 +406,12 @@ na_iduplicable_get_origin( const NAIDuplicable *object )
  * Since: 2.30
  */
 gboolean
-na_iduplicable_is_valid( const NAIDuplicable *object )
+fma_iduplicable_is_valid( const FMAIDuplicable *object )
 {
        gboolean is_valid;
        DuplicableStr *str;
 
-       g_return_val_if_fail( NA_IS_IDUPLICABLE( object ), FALSE );
+       g_return_val_if_fail( FMA_IS_IDUPLICABLE( object ), FALSE );
 
        str = get_duplicable_str( object );
        is_valid = str->valid;
@@ -420,8 +420,8 @@ na_iduplicable_is_valid( const NAIDuplicable *object )
 }
 
 /**
- * na_iduplicable_is_modified:
- * @object: the #NAIDuplicable object whose status is to be returned.
+ * fma_iduplicable_is_modified:
+ * @object: the #FMAIDuplicable object whose status is to be returned.
  *
  * Returns the current value of the 'is_modified'
  * property without rechecking the edition status itself.
@@ -432,12 +432,12 @@ na_iduplicable_is_valid( const NAIDuplicable *object )
  * Since: 2.30
  */
 gboolean
-na_iduplicable_is_modified( const NAIDuplicable *object )
+fma_iduplicable_is_modified( const FMAIDuplicable *object )
 {
        gboolean is_modified;
        DuplicableStr *str;
 
-       g_return_val_if_fail( NA_IS_IDUPLICABLE( object ), FALSE );
+       g_return_val_if_fail( FMA_IS_IDUPLICABLE( object ), FALSE );
 
        str = get_duplicable_str( object );
        is_modified = str->modified;
@@ -446,43 +446,43 @@ na_iduplicable_is_modified( const NAIDuplicable *object )
 }
 
 /**
- * na_iduplicable_set_origin:
- * @object: the #NAIDuplicable object whose origin is to be set.
- * @origin: the new original #NAIDuplicable.
+ * fma_iduplicable_set_origin:
+ * @object: the #FMAIDuplicable object whose origin is to be set.
+ * @origin: the new original #FMAIDuplicable.
  *
- * Sets the new origin of a duplicated #NAIDuplicable.
+ * Sets the new origin of a duplicated #FMAIDuplicable.
  *
  * Since: 2.30
  */
 void
-na_iduplicable_set_origin( NAIDuplicable *object, const NAIDuplicable *origin )
+fma_iduplicable_set_origin( FMAIDuplicable *object, const FMAIDuplicable *origin )
 {
        DuplicableStr *str;
 
-       g_return_if_fail( NA_IS_IDUPLICABLE( object ));
-       g_return_if_fail( NA_IS_IDUPLICABLE( origin ) || !origin );
+       g_return_if_fail( FMA_IS_IDUPLICABLE( object ));
+       g_return_if_fail( FMA_IS_IDUPLICABLE( origin ) || !origin );
 
        str = get_duplicable_str( object );
-       str->origin = ( NAIDuplicable * ) origin;
+       str->origin = ( FMAIDuplicable * ) origin;
 }
 
 #ifdef NA_ENABLE_DEPRECATED
 /**
- * na_iduplicable_set_modified:
- * @object: the #NAIDuplicable object whose modification status is to be set.
- * @modified: the new modification status #NAIDuplicable.
+ * fma_iduplicable_set_modified:
+ * @object: the #FMAIDuplicable object whose modification status is to be set.
+ * @modified: the new modification status #FMAIDuplicable.
  *
- * Sets the new modification status of a duplicated #NAIDuplicable.
+ * Sets the new modification status of a duplicated #FMAIDuplicable.
  *
  * Since: 2.30
  * Deprecated: 3.1
  */
 void
-na_iduplicable_set_modified( NAIDuplicable *object, gboolean modified )
+fma_iduplicable_set_modified( FMAIDuplicable *object, gboolean modified )
 {
        DuplicableStr *str;
 
-       g_return_if_fail( NA_IS_IDUPLICABLE( object ));
+       g_return_if_fail( FMA_IS_IDUPLICABLE( object ));
 
        str = get_duplicable_str( object );
        str->modified = modified;
@@ -490,35 +490,35 @@ na_iduplicable_set_modified( NAIDuplicable *object, gboolean modified )
 #endif /* NA_ENABLE_DEPRECATED */
 
 static void
-v_copy( NAIDuplicable *target, const NAIDuplicable *source, guint mode )
+v_copy( FMAIDuplicable *target, const FMAIDuplicable *source, guint mode )
 {
-       if( NA_IDUPLICABLE_GET_INTERFACE( target )->copy ){
-               NA_IDUPLICABLE_GET_INTERFACE( target )->copy( target, source, mode );
+       if( FMA_IDUPLICABLE_GET_INTERFACE( target )->copy ){
+               FMA_IDUPLICABLE_GET_INTERFACE( target )->copy( target, source, mode );
        }
 }
 
 static gboolean
-v_are_equal( const NAIDuplicable *a, const NAIDuplicable *b )
+v_are_equal( const FMAIDuplicable *a, const FMAIDuplicable *b )
 {
-       if( NA_IDUPLICABLE_GET_INTERFACE( a )->are_equal ){
-               return( NA_IDUPLICABLE_GET_INTERFACE( a )->are_equal( a, b ));
+       if( FMA_IDUPLICABLE_GET_INTERFACE( a )->are_equal ){
+               return( FMA_IDUPLICABLE_GET_INTERFACE( a )->are_equal( a, b ));
        }
 
        return( TRUE );
 }
 
 static gboolean
-v_is_valid( const NAIDuplicable *object )
+v_is_valid( const FMAIDuplicable *object )
 {
-       if( NA_IDUPLICABLE_GET_INTERFACE( object )->is_valid ){
-               return( NA_IDUPLICABLE_GET_INTERFACE( object )->is_valid( object ));
+       if( FMA_IDUPLICABLE_GET_INTERFACE( object )->is_valid ){
+               return( FMA_IDUPLICABLE_GET_INTERFACE( object )->is_valid( object ));
        }
 
        return( TRUE );
 }
 
 /**
- * na_iduplicable_register_consumer:
+ * fma_iduplicable_register_consumer:
  * @consumer: the target instance.
  *
  * This function registers a consumer, i.e. an instance to which edition
@@ -527,38 +527,38 @@ v_is_valid( const NAIDuplicable *object )
  * Since: 2.30
  */
 void
-na_iduplicable_register_consumer( GObject *consumer )
+fma_iduplicable_register_consumer( GObject *consumer )
 {
        g_return_if_fail( st_interface );
 
-       g_debug( "na_iduplicable_register_consumer: consumer=%p", ( void * ) consumer );
+       g_debug( "fma_iduplicable_register_consumer: consumer=%p", ( void * ) consumer );
 
        st_interface->private->consumers = g_list_prepend( st_interface->private->consumers, consumer );
 }
 
 static void
-on_modified_changed_class_handler( NAIDuplicable *instance, GObject *object, gboolean is_modified )
+on_modified_changed_class_handler( FMAIDuplicable *instance, GObject *object, gboolean is_modified )
 {
-       if( NA_IS_IDUPLICABLE( instance )){
+       if( FMA_IS_IDUPLICABLE( instance )){
                propagate_signal_to_consumers( instance, IDUPLICABLE_SIGNAL_MODIFIED_CHANGED, object, 
is_modified );
        }
 }
 
 static void
-on_valid_changed_class_handler( NAIDuplicable *instance, GObject *object, gboolean is_valid )
+on_valid_changed_class_handler( FMAIDuplicable *instance, GObject *object, gboolean is_valid )
 {
-       if( NA_IS_IDUPLICABLE( instance )){
+       if( FMA_IS_IDUPLICABLE( instance )){
                propagate_signal_to_consumers( instance, IDUPLICABLE_SIGNAL_VALID_CHANGED, object, is_valid );
        }
 }
 
 static void
-propagate_signal_to_consumers( NAIDuplicable *instance, const gchar *signal, GObject *object, gboolean 
new_status )
+propagate_signal_to_consumers( FMAIDuplicable *instance, const gchar *signal, GObject *object, gboolean 
new_status )
 {
-       static const gchar *thisfn = "na_iduplicable_propagate_signals_to_consumers";
+       static const gchar *thisfn = "fma_iduplicable_propagate_signals_to_consumers";
        GList *ic;
 
-       g_return_if_fail( NA_IS_IDUPLICABLE( instance ));
+       g_return_if_fail( FMA_IS_IDUPLICABLE( instance ));
 
        g_debug( "%s: instance=%p, signal=%s", thisfn, ( void * ) instance, signal );
 
@@ -574,11 +574,11 @@ release_signal_consumers( GList *consumers )
 }
 
 static DuplicableStr *
-get_duplicable_str( const NAIDuplicable *object )
+get_duplicable_str( const FMAIDuplicable *object )
 {
        DuplicableStr *str;
 
-       str = ( DuplicableStr * ) g_object_get_data( G_OBJECT( object ), NA_IDUPLICABLE_DATA_DUPLICABLE );
+       str = ( DuplicableStr * ) g_object_get_data( G_OBJECT( object ), FMA_IDUPLICABLE_DATA_DUPLICABLE );
 
        if( !str ){
                str = g_new0( DuplicableStr, 1 );
@@ -587,7 +587,7 @@ get_duplicable_str( const NAIDuplicable *object )
                str->modified = FALSE;
                str->valid = TRUE;
 
-               g_object_set_data( G_OBJECT( object ), NA_IDUPLICABLE_DATA_DUPLICABLE, str );
+               g_object_set_data( G_OBJECT( object ), FMA_IDUPLICABLE_DATA_DUPLICABLE, str );
        }
 
        return( str );
diff --git a/src/core/na-marshal.def b/src/core/na-marshal.def
index 5578e08..b948079 100644
--- a/src/core/na-marshal.def
+++ b/src/core/na-marshal.def
@@ -1,5 +1,5 @@
-# NAIDuplicable:: IDUPLICABLE_SIGNAL_MODIFIED_CHANGED
-# NAIDuplicable:: IDUPLICABLE_SIGNAL_VALID_CHANGED
+# FMAIDuplicable:: IDUPLICABLE_SIGNAL_MODIFIED_CHANGED
+# FMAIDuplicable:: IDUPLICABLE_SIGNAL_VALID_CHANGED
 VOID:POINTER,BOOLEAN
 #
 # NASettings:: SETTINGS_SIGNAL_KEY_CHANGED
diff --git a/src/core/na-object-item.c b/src/core/na-object-item.c
index a6a0062..caa7f75 100644
--- a/src/core/na-object-item.c
+++ b/src/core/na-object-item.c
@@ -273,7 +273,7 @@ object_copy( NAObject *target, const NAObject *source, guint mode )
  * @a: the first (original) #NAObjectItem instance.
  * @b: the second #NAObjectItem instance.
  *
- * This function participates to the #na_iduplicable_check_status() stack,
+ * This function participates to the #fma_iduplicable_check_status() stack,
  * and is triggered after all comparable elementary data (in #NAIFactoryObject
  * sense) have already been successfully compared.
  *
diff --git a/src/nact/nact-assistant-export.c b/src/nact/nact-assistant-export.c
index c4ee778..b2d96df 100644
--- a/src/nact/nact-assistant-export.c
+++ b/src/nact/nact-assistant-export.c
@@ -774,7 +774,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
                str = g_new0( ExportStruct, 1 );
                window->private->results = g_list_append( window->private->results, str );
 
-               str->item = NA_OBJECT_ITEM( na_object_get_origin( NA_IDUPLICABLE( ia->data )));
+               str->item = NA_OBJECT_ITEM( na_object_get_origin( FMA_IDUPLICABLE( ia->data )));
                str->format = na_settings_get_string( NA_IPREFS_EXPORT_PREFERRED_FORMAT, NULL, NULL );
                g_return_if_fail( str->format && strlen( str->format ));
 
diff --git a/src/nact/nact-clipboard.c b/src/nact/nact-clipboard.c
index 245997b..c7510ad 100644
--- a/src/nact/nact-clipboard.c
+++ b/src/nact/nact-clipboard.c
@@ -662,7 +662,7 @@ export_row_object( NactClipboard *clipboard, NAObject *object, const gchar *dest
  * which has the same characteristics that the previous one ; we so
  * have to renumber actions/menus items when copying into the clipboard.
  *
- * Note that we use NAIDuplicable interface without actually taking care
+ * Note that we use FMAIDuplicable interface without actually taking care
  * of what is origin or so, as origin will be reinitialized when getting
  * data out of the clipboard.
  */
diff --git a/src/nact/nact-tree-ieditable.c b/src/nact/nact-tree-ieditable.c
index 00d6766..e72b50b 100644
--- a/src/nact/nact-tree-ieditable.c
+++ b/src/nact/nact-tree-ieditable.c
@@ -203,7 +203,7 @@ nact_tree_ieditable_initialize( NactTreeIEditable *instance, GtkTreeView *treevi
        g_signal_connect( renderers->data, "edited", G_CALLBACK( on_label_edited ), instance );
 
        /* monitors status changes to refresh the display */
-       na_iduplicable_register_consumer( G_OBJECT( instance ));
+       fma_iduplicable_register_consumer( G_OBJECT( instance ));
        ied->modified_handler_id =
                        g_signal_connect(
                                        instance, IDUPLICABLE_SIGNAL_MODIFIED_CHANGED,



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/api/na-iduplicable.h b/src/api/fma-iduplicable.h
similarity index 68%
rename from src/api/na-iduplicable.h
rename to src/api/fma-iduplicable.h
index 469e830..3d301db 100644
--- a/src/api/na-iduplicable.h
+++ b/src/api/fma-iduplicable.h
@@ -27,14 +27,14 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_IDUPLICABLE_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_IDUPLICABLE_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_IDUPLICABLE_H__
+#define __FILE_MANAGER_ACTIONS_API_IDUPLICABLE_H__
 
 /**
  * SECTION: iduplicable
- * @title: NAIDuplicable
+ * @title: FMAIDuplicable
  * @short_description: The Duplication Interface
- * @include: file-manager-actions/private/na-iduplicable.h
+ * @include: file-manager-actions/private/fma-iduplicable.h
  *
  * This interface is implemented by #NAObject in order to let
  * #NAObject -derived instance duplication be easily tracked. This works
@@ -77,7 +77,7 @@
  * <refsect2>
  *  <title>Versions historic</title>
  *  <table>
  *    <title>Historic of the versions of the #NAIDuplicable interface</title>
  *    <tgroup rowsep="1" colsep="1" align="center" cols="3">
  *      <colspec colname="na-version" />
  *      <colspec colname="api-version" />
@@ -85,7 +85,7 @@
  *      <thead>
  *        <row>
  *          <entry>&prodname; version</entry>
- *          <entry>#NAIDuplicable interface version</entry>
+ *          <entry>#FMAIDuplicable interface version</entry>
  *          <entry></entry>
  *        </row>
  *      </thead>
@@ -105,16 +105,16 @@
 
 G_BEGIN_DECLS
 
-#define NA_TYPE_IDUPLICABLE                      ( na_iduplicable_get_type())
-#define NA_IDUPLICABLE( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, 
NA_TYPE_IDUPLICABLE, NAIDuplicable ))
-#define NA_IS_IDUPLICABLE( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_TYPE_IDUPLICABLE 
))
-#define NA_IDUPLICABLE_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), 
NA_TYPE_IDUPLICABLE, NAIDuplicableInterface ))
+#define FMA_TYPE_IDUPLICABLE                      ( fma_iduplicable_get_type())
+#define FMA_IDUPLICABLE( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, 
FMA_TYPE_IDUPLICABLE, FMAIDuplicable ))
+#define FMA_IS_IDUPLICABLE( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, 
FMA_TYPE_IDUPLICABLE ))
+#define FMA_IDUPLICABLE_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), 
FMA_TYPE_IDUPLICABLE, FMAIDuplicableInterface ))
 
-typedef struct _NAIDuplicable                    NAIDuplicable;
-typedef struct _NAIDuplicableInterfacePrivate    NAIDuplicableInterfacePrivate;
+typedef struct _FMAIDuplicable                    FMAIDuplicable;
+typedef struct _FMAIDuplicableInterfacePrivate    FMAIDuplicableInterfacePrivate;
 
 /**
- * NAIDuplicableInterface:
+ * FMAIDuplicableInterface:
  * @copy:      copies one object to another.
  * @are_equal: tests if two objects are equals.
  * @is_valid:  tests if one object is valid.
@@ -125,13 +125,13 @@ typedef struct _NAIDuplicableInterfacePrivate    NAIDuplicableInterfacePrivate;
 typedef struct {
        /*< private >*/
        GTypeInterface                 parent;
-       NAIDuplicableInterfacePrivate *private;
+       FMAIDuplicableInterfacePrivate *private;
 
        /*< public >*/
        /**
         * copy:
         * @target: the #NAIDuplicable target of the copy.
         * @source: the #NAIDuplicable source of the copy.
         * @mode: the duplication mode.
         *
         * Copies data from @source to @ŧarget, so that @target becomes an
@@ -144,12 +144,12 @@ typedef struct {
         *
         * Since: 2.30
         */
-       void     ( *copy )      ( NAIDuplicable *target, const NAIDuplicable *source, guint mode );
+       void     ( *copy )      ( FMAIDuplicable *target, const FMAIDuplicable *source, guint mode );
 
        /**
         * are_equal:
         * @a: a first #NAIDuplicable object.
         * @b: a second #NAIDuplicable object to be compared to the first
         * one.
         *
         * Compares the two objects.
@@ -166,11 +166,11 @@ typedef struct {
         *
         * Since: 2.30
         */
-       gboolean ( *are_equal ) ( const NAIDuplicable *a, const NAIDuplicable *b );
+       gboolean ( *are_equal ) ( const FMAIDuplicable *a, const FMAIDuplicable *b );
 
        /**
         * is_valid:
         * @object: the NAIDuplicable object to be checked.
         *
         * Checks @object for validity.
         *
@@ -183,9 +183,9 @@ typedef struct {
         *
         * Since: 2.30
         */
-       gboolean ( *is_valid )  ( const NAIDuplicable *object );
+       gboolean ( *is_valid )  ( const FMAIDuplicable *object );
 }
-       NAIDuplicableInterface;
+       FMAIDuplicableInterface;
 
 #define IDUPLICABLE_SIGNAL_MODIFIED_CHANGED            "iduplicable-modified-changed"
 #define IDUPLICABLE_SIGNAL_VALID_CHANGED               "iduplicable-valid-changed"
@@ -204,25 +204,25 @@ typedef enum {
 }
        DuplicableMode;
 
-GType          na_iduplicable_get_type         ( void );
+GType          fma_iduplicable_get_type         ( void );
 
-void           na_iduplicable_dispose          ( const NAIDuplicable *object );
-void           na_iduplicable_dump             ( const NAIDuplicable *object );
-NAIDuplicable *na_iduplicable_duplicate        ( const NAIDuplicable *object, guint mode );
-void           na_iduplicable_check_status     ( const NAIDuplicable *object );
+void           fma_iduplicable_dispose          ( const FMAIDuplicable *object );
+void           fma_iduplicable_dump             ( const FMAIDuplicable *object );
+FMAIDuplicable *fma_iduplicable_duplicate        ( const FMAIDuplicable *object, guint mode );
+void           fma_iduplicable_check_status     ( const FMAIDuplicable *object );
 
-NAIDuplicable *na_iduplicable_get_origin       ( const NAIDuplicable *object );
-gboolean       na_iduplicable_is_valid         ( const NAIDuplicable *object );
-gboolean       na_iduplicable_is_modified      ( const NAIDuplicable *object );
+FMAIDuplicable *fma_iduplicable_get_origin       ( const FMAIDuplicable *object );
+gboolean       fma_iduplicable_is_valid         ( const FMAIDuplicable *object );
+gboolean       fma_iduplicable_is_modified      ( const FMAIDuplicable *object );
 
-void           na_iduplicable_set_origin       ( NAIDuplicable *object, const NAIDuplicable *origin );
+void           fma_iduplicable_set_origin       ( FMAIDuplicable *object, const FMAIDuplicable *origin );
 
-void           na_iduplicable_register_consumer( GObject *consumer );
+void           fma_iduplicable_register_consumer( GObject *consumer );
 
 #ifdef NA_ENABLE_DEPRECATED
-void           na_iduplicable_set_modified( NAIDuplicable *object, gboolean modified );
+void           fma_iduplicable_set_modified( FMAIDuplicable *object, gboolean modified );
 #endif
 
 G_END_DECLS
 
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_IDUPLICABLE_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_IDUPLICABLE_H__ */
@@ -77,7 +77,7 @@
  *  <title>Versions historic</title>
  *  <table>
- *    <title>Historic of the versions of the #NAIDuplicable interface</title>
+ *    <title>Historic of the versions of the #FMAIDuplicable interface</title>
  *    <tgroup rowsep="1" colsep="1" align="center" cols="3">
  *      <colspec colname="na-version" />
@@ -125,13 +125,13 @@ typedef struct _NAIDuplicableInterfacePrivate    NAIDuplicableInterfacePrivate;
        /**
         * copy:
-        * @target: the #NAIDuplicable target of the copy.
-        * @source: the #NAIDuplicable source of the copy.
+        * @target: the #FMAIDuplicable target of the copy.
+        * @source: the #FMAIDuplicable source of the copy.
         * @mode: the duplication mode.
         *
@@ -144,12 +144,12 @@ typedef struct {
        /**
         * are_equal:
-        * @a: a first #NAIDuplicable object.
-        * @b: a second #NAIDuplicable object to be compared to the first
+        * @a: a first #FMAIDuplicable object.
+        * @b: a second #FMAIDuplicable object to be compared to the first
         * one.
         *
@@ -166,11 +166,11 @@ typedef struct {
        /**
         * is_valid:
-        * @object: the NAIDuplicable object to be checked.
+        * @object: the FMAIDuplicable object to be checked.
         *
         * Checks @object for validity.
diff --git a/src/core/na-object.c b/src/core/na-object.c
index 2471d00..3ad5cf8 100644
--- a/src/core/na-object.c
+++ b/src/core/na-object.c
@@ -57,10 +57,10 @@ static void     instance_finalize( GObject *object );
 
 static void     object_dump( const NAObject *object );
 
-static void     iduplicable_iface_init( NAIDuplicableInterface *iface, void *user_data );
-static void     iduplicable_copy( NAIDuplicable *target, const NAIDuplicable *source, guint mode );
-static gboolean iduplicable_are_equal( const NAIDuplicable *a, const NAIDuplicable *b );
-static gboolean iduplicable_is_valid( const NAIDuplicable *object );
+static void     iduplicable_iface_init( FMAIDuplicableInterface *iface, void *user_data );
+static void     iduplicable_copy( FMAIDuplicable *target, const FMAIDuplicable *source, guint mode );
+static gboolean iduplicable_are_equal( const FMAIDuplicable *a, const FMAIDuplicable *b );
+static gboolean iduplicable_is_valid( const FMAIDuplicable *object );
 
 static void     check_status_down_rec( const NAObject *object );
 static void     check_status_up_rec( const NAObject *object, gboolean was_modified, gboolean was_valid );
@@ -109,7 +109,7 @@ register_type( void )
 
        type = g_type_register_static( G_TYPE_OBJECT, "NAObject", &info, 0 );
 
-       g_type_add_interface_static( type, NA_TYPE_IDUPLICABLE, &iduplicable_iface_info );
+       g_type_add_interface_static( type, FMA_TYPE_IDUPLICABLE, &iduplicable_iface_info );
 
        return( type );
 }
@@ -163,7 +163,7 @@ instance_dispose( GObject *object )
 
                self->private->dispose_has_run = TRUE;
 
-               na_iduplicable_dispose( NA_IDUPLICABLE( object ));
+               fma_iduplicable_dispose( FMA_IDUPLICABLE( object ));
 
                /* chain up to the parent class */
                if( G_OBJECT_CLASS( st_parent_class )->dispose ){
@@ -198,7 +198,7 @@ object_dump( const NAObject *object )
 {
        if( !object->private->dispose_has_run ){
 
-               na_iduplicable_dump( NA_IDUPLICABLE( object ));
+               fma_iduplicable_dump( FMA_IDUPLICABLE( object ));
 
                if( NA_IS_IFACTORY_OBJECT( object )){
                        na_factory_object_dump( NA_IFACTORY_OBJECT( object ));
@@ -207,7 +207,7 @@ object_dump( const NAObject *object )
 }
 
 static void
-iduplicable_iface_init( NAIDuplicableInterface *iface, void *user_data )
+iduplicable_iface_init( FMAIDuplicableInterface *iface, void *user_data )
 {
        static const gchar *thisfn = "na_object_iduplicable_iface_init";
 
@@ -219,11 +219,11 @@ iduplicable_iface_init( NAIDuplicableInterface *iface, void *user_data )
 }
 
 /*
  * implementation of na_iduplicable::copy interface virtual function
  * it recursively copies @source to @target
  */
 static void
-iduplicable_copy( NAIDuplicable *target, const NAIDuplicable *source, guint mode )
+iduplicable_copy( FMAIDuplicable *target, const FMAIDuplicable *source, guint mode )
 {
        static const gchar *thisfn = "na_object_iduplicable_copy";
        NAObject *dest, *src;
@@ -256,7 +256,7 @@ iduplicable_copy( NAIDuplicable *target, const NAIDuplicable *source, guint mode
 }
 
 static gboolean
-iduplicable_are_equal( const NAIDuplicable *a, const NAIDuplicable *b )
+iduplicable_are_equal( const FMAIDuplicable *a, const FMAIDuplicable *b )
 {
        static const gchar *thisfn = "na_object_iduplicable_are_equal";
        gboolean are_equal;
@@ -288,7 +288,7 @@ iduplicable_are_equal( const NAIDuplicable *a, const NAIDuplicable *b )
 }
 
 static gboolean
-iduplicable_is_valid( const NAIDuplicable *object )
+iduplicable_is_valid( const FMAIDuplicable *object )
 {
        static const gchar *thisfn = "na_object_iduplicable_is_valid";
        gboolean is_valid;
@@ -328,7 +328,7 @@ iduplicable_is_valid( const NAIDuplicable *object )
  *
  * <literallayout>
  * na_object_object_check_status_rec( object )
- *  +- na_iduplicable_check_status( object )
+ *  +- fma_iduplicable_check_status( object )
  *      +- get_origin( object )
  *      +- modified_status = v_are_equal( origin, object )
  *      |  +-> interface <structfield>NAObjectClass::are_equal</structfield>
@@ -402,7 +402,7 @@ check_status_down_rec( const NAObject *object )
                g_list_foreach( na_object_get_items( object ), ( GFunc ) check_status_down_rec, NULL );
        }
 
-       na_iduplicable_check_status( NA_IDUPLICABLE( object ));
+       fma_iduplicable_check_status( FMA_IDUPLICABLE( object ));
 }
 
 /*
@@ -426,7 +426,7 @@ check_status_up_rec( const NAObject *object, gboolean was_modified, gboolean was
                        if( parent ){
                                was_modified = na_object_is_modified( parent );
                                was_valid = na_object_is_valid( parent );
-                               na_iduplicable_check_status( NA_IDUPLICABLE( parent ));
+                               fma_iduplicable_check_status( FMA_IDUPLICABLE( parent ));
                                check_status_up_rec( NA_OBJECT( parent ), was_modified, was_valid );
                        }
        }
@@ -594,8 +594,8 @@ na_object_object_reset_origin( NAObject *object, const NAObject *origin )
                        na_object_reset_origin( iobj->data, iorig->data );
                }
 
-               na_iduplicable_set_origin( NA_IDUPLICABLE( object ), NA_IDUPLICABLE( origin ));
-               na_iduplicable_set_origin( NA_IDUPLICABLE( origin ), NULL );
+               fma_iduplicable_set_origin( FMA_IDUPLICABLE( object ), FMA_IDUPLICABLE( origin ));
+               fma_iduplicable_set_origin( FMA_IDUPLICABLE( origin ), NULL );
        }
 }
 
@@ -219,11 +219,11 @@ iduplicable_iface_init( NAIDuplicableInterface *iface, void *user_data )
 
 /*
- * implementation of na_iduplicable::copy interface virtual function
+ * implementation of fma_iduplicable::copy interface virtual function
  * it recursively copies @source to @target
  */